describe('VnLocation', () => {
    const locationOptions = '[role="listbox"] > div.q-virtual-scroll__content > .q-item';
    const dialogInputs = '.q-dialog label input';
    const createLocationButton = '.q-form > .q-card > .vn-row:nth-child(6) .--add-icon';
    const inputLocation = '.q-form input[aria-label="Location"]';
    const createForm = {
        prefix: '.q-dialog__inner > .column > #formModel > .q-card',
        sufix: ' .q-field__inner > .q-field__control',
    };
    describe('CreateFormDialog ', () => {
        beforeEach(() => {
            cy.viewport(1280, 720);
            cy.login('developer');
            cy.visit('/#/supplier/567/fiscal-data', { timeout: 7000 });
            cy.domContentLoad();
            cy.get(createLocationButton).click();
        });
        it('should filter provinces based on selected country', () => {
            // Select a country
            cy.selectOption(
                `${createForm.prefix} > :nth-child(5) > .q-field:nth-child(5)> ${createForm.sufix}`,
                'Ecuador'
            );
            // Verify that provinces are filtered
            cy.get(
                `${createForm.prefix} > :nth-child(5) > .q-field:nth-child(3)> ${createForm.sufix}`
            ).should('have.length', 1);

            // Verify that towns are filtered
            cy.get(
                `${createForm.prefix} > :nth-child(4) > .q-field:nth-child(3)> ${createForm.sufix}`
            ).should('have.length', 1);
        });

        it('should filter towns based on selected province', () => {
            // Select a country
            cy.selectOption(
                `${createForm.prefix} > :nth-child(5) > .q-field:nth-child(3)> ${createForm.sufix}`,
                'Ecuador'
            );
            // Verify that provinces are filtered
            cy.get(
                `${createForm.prefix} > :nth-child(5) > .q-field:nth-child(3)> ${createForm.sufix}`
            ).should('have.length', 1);

            // Verify that towns are filtered
            cy.get(
                `${createForm.prefix} > :nth-child(4) > .q-field:nth-child(3)> ${createForm.sufix}`
            ).should('have.length', 1);
        });
        it('should pass selected country', () => {
            // Select a country
            const country = 'Ecuador';
            const province = 'Province five';
            cy.selectOption(
                `${createForm.prefix} > :nth-child(5) > .q-field:nth-child(5)> ${createForm.sufix}`,
                country
            );
            cy.selectOption(
                `${createForm.prefix} > :nth-child(4) > .q-select > ${createForm.sufix}`,
                province
            );
            cy.get(
                `${createForm.prefix} > :nth-child(4) > .q-select > ${createForm.sufix} > :nth-child(3) > .q-icon`
            ).click();
            cy.get(
                `#q-portal--dialog--5 > .q-dialog > ${createForm.prefix} > .vn-row > .q-select > ${createForm.sufix} > :nth-child(1) input`
            ).should('have.value', province);
        });
    });
    describe('Worker Create', () => {
        beforeEach(() => {
            cy.viewport(1280, 720);
            cy.login('developer');
            cy.visit('/#/worker/create', { timeout: 5000 });
            cy.waitForElement('.q-card');
            cy.get(inputLocation).click();
        });
        it('Show all options', function () {
            cy.get(locationOptions).should('have.length.at.least', 5);
        });
        it('input filter location as "al"', function () {
            // cy.get(inputLocation).click();
            cy.get(inputLocation).clear();
            cy.get(inputLocation).type('al');
            cy.get(locationOptions).should('have.length.at.least', 4);
        });
        it('input filter location as "ecuador"', function () {
            // cy.get(inputLocation).click();
            cy.get(inputLocation).clear();
            cy.get(inputLocation).type('ecuador');
            cy.get(locationOptions).should('have.length.at.least', 1);
        });
    });
    describe('Fiscal-data', () => {
        beforeEach(() => {
            cy.viewport(1280, 720);
            cy.login('developer');
            cy.visit('/#/supplier/567/fiscal-data', { timeout: 7000 });
            cy.waitForElement('.q-form');
        });
        it('Find by postalCode', () => {
            const postCode = '46600';
            const postCodeLabel = '46600, Valencia(Province one), España';
            const firstOption = '[role="listbox"] .q-item:nth-child(1)';

            cy.get(inputLocation).click();
            cy.get(inputLocation).clear();
            cy.get(inputLocation).type(postCode);
            cy.get(locationOptions)
                .get(':nth-child(1)')
                .should('have.length.at.least', 2);
            cy.get(
                firstOption.concat(' > .q-item__section > .q-item__label--caption')
            ).should('have.text', postCodeLabel);
            cy.get(firstOption).click();
            cy.get('.q-btn-group > .q-btn--standard > .q-btn__content > .q-icon').click();
            cy.reload();
            cy.waitForElement('.q-form');
            cy.get(inputLocation).should('have.value', postCodeLabel);
        });

        it('Create postCode', () => {
            const postCode = '1234475';
            const province = 'Valencia';
            cy.get(createLocationButton).click();
            cy.get('.q-card > h1').should('have.text', 'New postcode');
            cy.get(dialogInputs).eq(0).clear();
            cy.get(dialogInputs).eq(0).type(postCode);
            cy.selectOption(
                `${createForm.prefix} > :nth-child(4) > .q-select > ${createForm.sufix}`,
                province
            );
            cy.get('.q-mt-lg > .q-btn--standard').click();
            cy.get(`${createForm.prefix}`).should('not.exist');
            cy.waitForElement('.q-form');

            checkVnLocation(postCode, province);
        });
        it('Create city', () => {
            const postCode = '9011';
            const province = 'Saskatchew';
            cy.get(createLocationButton).click();
            cy.get(dialogInputs).eq(0).type(postCode);
            // city create button
            cy.get(
                `${createForm.prefix} > :nth-child(4) > .q-select > ${createForm.sufix} > :nth-child(2) > .q-icon`
            ).click();
            cy.selectOption('#q-portal--dialog--3 .q-select', 'one');
            cy.get('#q-portal--dialog--3 .q-input').type(province);
            cy.get('#q-portal--dialog--3 .q-btn--standard').click();
            cy.get('#q-portal--dialog--1 .q-btn--standard').click();
            cy.waitForElement('.q-form');

            checkVnLocation(postCode, province);
        });

        function checkVnLocation(postCode, province) {
            cy.get(`${createForm.prefix}`).should('not.exist');
            cy.get('.q-form > .q-card > .vn-row:nth-child(6)')
                .find('input')
                .invoke('val')
                .then((text) => {
                    expect(text).to.contain(postCode);
                    expect(text).to.contain(province);
                });
        }
    });
});
